@@ -139,17 +139,13 @@ class App:
             self.cur_resp.set_cookie(key, value, secure=secure)
         else:
             self.cur_resp.set_cookie(
-                key, value, expires=lifetime, secure=secure)
+                key, value, max_age=lifetime, secure=secure)
 
     def get_cookies(self):
         return self.cur_req.cookies
 
     def get_cookie(self, key):
-        cookies = {}
-        for key, value in dict(self.cur_req.cookies).items():
-            if key not in ["hblid", "olfsk"]:
-                cookies[key] = value
-        return cookies
+        return self.cur_req.cookies()
 
     def run(self):
         try:
